@@ -10,17 +10,17 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.32-642.11.1.el6.src.rpm ]
+if [ ! -r kernel-2.6.32-642.13.1.el6.src.rpm ]
 then
-    wget http://vault.centos.org/6.8/updates/Source/SPackages/kernel-2.6.32-642.11.1.el6.src.rpm || die "Can't download source package."
+    wget http://vault.centos.org/6.8/updates/Source/SPackages/kernel-2.6.32-642.13.1.el6.src.rpm || die "Can't download source package."
 fi
-LANG=C rpm --checksig kernel-2.6.32-642.11.1.el6.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
-rpm -ivh kernel-2.6.32-642.11.1.el6.src.rpm || die "Can't install source package."
+LANG=C rpm --checksig kernel-2.6.32-642.13.1.el6.src.rpm | grep -F ': rsa sha1 (md5) pgp md5 OK' || die "Can't verify signature."
+rpm -ivh kernel-2.6.32-642.13.1.el6.src.rpm || die "Can't install source package."
 
 cd ~/rpmbuild/SOURCES/ || die "Can't chdir to ~/rpmbuild/SOURCES/ ."
-if [ ! -r caitsith-patch-0.2-20161229.tar.gz ]
+if [ ! -r caitsith-patch-0.2-20170220.tar.gz ]
 then
-    wget -O caitsith-patch-0.2-20161229.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/66537/caitsith-patch-0.2-20161229.tar.gz' || die "Can't download patch."
+    wget -O caitsith-patch-0.2-20170220.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/66537/caitsith-patch-0.2-20170220.tar.gz' || die "Can't download patch."
 fi
 
 cd ~/rpmbuild/SPECS/ || die "Can't chdir to ~/rpmbuild/SPECS/ ."
@@ -33,9 +33,9 @@ patch << "EOF" || die "Can't patch spec file."
  # by setting the define to ".local" or ".bz123456"
  #
 -# % define buildid .local
-+%define buildid _caitsith_0.2
++%define buildid _caitsith_0.2.1
  
- %define distro_build 642.11.1
+ %define distro_build 642.13.1
  %define signmodules 1
 @@ -437,7 +437,7 @@
  # Packages that need to be installed before the kernel is, because the %post
@@ -69,7 +69,7 @@ patch << "EOF" || die "Can't patch spec file."
  ApplyOptionalPatch linux-kernel-test.patch
  
 +# CaitSith
-+tar -zxf %_sourcedir/caitsith-patch-0.2-20161229.tar.gz
++tar -zxf %_sourcedir/caitsith-patch-0.2-20170220.tar.gz
 +sed -i -e 's/CCSECURITY/CAITSITH/g' -e 's/ccsecurity/caitsith/g' -e 's/ccs_domain_info/cs_domain_info/g' -e 's/ccs_flags/cs_flags/g' patches/ccs-patch-*.diff
 +patch -sp1 < patches/ccs-patch-2.6.32-centos-6.diff
  # Any further pre-build tree manipulations happen here.
