@@ -18,9 +18,9 @@ LANG=C rpm --checksig kernel-3.4.110-4vl6.src.rpm | grep -F ': (sha1) dsa sha1 m
 rpm -ivh kernel-3.4.110-4vl6.src.rpm || die "Can't install source package."
 
 cd ~/rpm/SOURCES/ || die "Can't chdir to ~/rpm/SOURCES/ ."
-if [ ! -r caitsith-patch-0.2-20161229.tar.gz ]
+if [ ! -r caitsith-patch-0.2-20170220.tar.gz ]
 then
-    wget -O caitsith-patch-0.2-20161229.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/66537/caitsith-patch-0.2-20161229.tar.gz' || die "Can't download patch."
+    wget -O caitsith-patch-0.2-20170220.tar.gz 'http://osdn.jp/frs/redir.php?f=/caitsith/66537/caitsith-patch-0.2-20170220.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -33,7 +33,7 @@ patch << "EOF" || die "Can't patch spec file."
  %define kversion 3.%{sublevel}
  %define rpmversion 3.%{sublevel}.%{patchlevel}
 -%define release 4%{?_dist_release}
-+%define release 4%{?_dist_release}_caitsith_0.2
++%define release 4%{?_dist_release}_caitsith_0.2.1
  
  %define make_target bzImage
  %define hdrarch %_target_cpu
@@ -61,7 +61,7 @@ patch << "EOF" || die "Can't patch spec file."
  # END OF PATCH APPLICATIONS
  
 +# CaitSith
-+tar -zxf %_sourcedir/caitsith-patch-0.2-20161229.tar.gz
++tar -zxf %_sourcedir/caitsith-patch-0.2-20170220.tar.gz
 +sed -i -e 's/CCSECURITY/CAITSITH/g' -e 's/ccsecurity/caitsith/g' -e 's/ccs_domain_info/cs_domain_info/g' -e 's/ccs_flags/cs_flags/g' patches/ccs-patch-*.diff
 +patch -sp1 < patches/ccs-patch-3.4-vine-linux-6.diff
  cp %{SOURCE10} Documentation/
