@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2012  NTT DATA CORPORATION
  *
- * Version: 0.2   2016/10/05
+ * Version: 0.2.1   2017/02/20
  */
 
 #include <linux/path.h>
@@ -268,6 +268,16 @@ static struct security_hook_list caitsith_hooks[] = {
 
 static void cs_add_hooks(void)
 {
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(4, 11, 0)
+	int i;
+
+	for (i = 0; i < ARRAY_SIZE(caitsith_hooks); i++) {
+		caitsith_hooks[i].lsm = "caitsith";
+		list_add_tail_rcu(&caitsith_hooks[i].list,
+				  caitsith_hooks[i].head);
+	}
+#else
 	security_add_hooks(caitsith_hooks, ARRAY_SIZE(caitsith_hooks));
+#endif
 }
 #endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(4, 2, 0) && defined(CONFIG_SECURITY) */
