@@ -47,3 +47,7 @@ void * __init probe___d_path(void);
 #else
 void * __init probe_d_absolute_path(void);
 #endif
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(2, 6, 29)
+void * __init probe_ksize(void);
+#endif
